@@ -1,25 +1,25 @@
-#import <swarmobject.h>
-#import <collections.h>
-#import <tkobjc/Raster.h>
+#import <objectbase/SwarmObject.h>
+#import <gui.h>
 
-@interface Tree: SwarmObject {
+@interface Tree: SwarmObject
+{
 
 @public
 
 //              Species
 //-----------------------------------
 
-  id species ;
+  id species;
    
 //              Mortality
 //-----------------------------------
 
-  int age ;
+  int age;
 
 //              Disturbance
 //-----------------------------------
 
-  int totalHeat ;
+  int totalHeat;
 
 //              Growth
 //----------------------------------
@@ -27,7 +27,7 @@
 //              Fecundity
 //-----------------------------------
 
-  int seedingCounter ;
+  int seedingCounter;
 
 //              Location
 //-----------------------------------
@@ -40,25 +40,25 @@
 //             SpeedHack
 //-----------------------------------
 
-  member_t listMembership ;
+  member_t listMembership;
 }
 
--setSpecies: aSpecies ;
--setAge: (int) anAge ;
--setSeedingCounter: (int) aYear ;
--createEnd;
+- setSpecies: aSpecies;
+- setAge: (int)anAge;
+- setSeedingCounter: (int)aYear;
+- createEnd;
 
--(int) getAge; 
--(int) getX ;
--(int) getY ;
--getSpecies ;
--clearSeedingCounter ;
--(int) incSeedingCounter ;
--(int) incAge ;
--setX: (int) x Y: (int) y;			
--step;
--burn;
--fireWithHeat: (int) theHeat ;
--drawSelfOn: (Raster *) r;
--(int) getSpeciesIdentifier ;
+- (int)getAge; 
+- (int)getX;
+- (int)getY;
+- getSpecies;
+- clearSeedingCounter;
+- (int) incSeedingCounter;
+- (int) incAge;
+- setX: (int)x Y: (int)y;			
+- step;
+- burn;
+- fireWithHeat: (int)theHeat;
+- drawSelfOn: (id <Raster>)r;
+- (int)getSpeciesIdentifier;
 @end
