@@ -1,4 +1,4 @@
-#import <swarmobject.h>
+#import <objectbase.h>
 #import "Forest.h"
 
 @interface YoungForest: Forest {
